==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/NotificationRegistrationPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.NotificationRegistrationPropertiesArgs.builder
import com.pulumi.azurenative.providerhub.kotlin.enums.MessageScope
import com.pulumi.azurenative.providerhub.kotlin.enums.NotificationMode
import com.pulumi.azurenative.providerhub.kotlin.enums.ProvisioningState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property includedEvents
 * @property messageScope
 * @property notificationEndpoints
 * @property notificationMode
 * @property provisioningState The provisioned state of the resource.
 */
public data class NotificationRegistrationPropertiesArgs(
    public val includedEvents: Output<List<String>>? = null,
    public val messageScope: Output<Either<String, MessageScope>>? = null,
    public val notificationEndpoints: Output<List<NotificationEndpointArgs>>? = null,
    public val notificationMode: Output<Either<String, NotificationMode>>? = null,
    public val provisioningState: Output<Either<String, ProvisioningState>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.NotificationRegistrationPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.NotificationRegistrationPropertiesArgs =
        com.pulumi.azurenative.providerhub.inputs.NotificationRegistrationPropertiesArgs.builder()
            .includedEvents(includedEvents?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .messageScope(
                messageScope?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .notificationEndpoints(
                notificationEndpoints?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .notificationMode(
                notificationMode?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .provisioningState(
                provisioningState?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            ).build()
}

/**
 * Builder for [NotificationRegistrationPropertiesArgs].
 */
@PulumiTagMarker
public class NotificationRegistrationPropertiesArgsBuilder internal constructor() {
    private var includedEvents: Output<List<String>>? = null

    private var messageScope: Output<Either<String, MessageScope>>? = null

    private var notificationEndpoints: Output<List<NotificationEndpointArgs>>? = null

    private var notificationMode: Output<Either<String, NotificationMode>>? = null

    private var provisioningState: Output<Either<String, ProvisioningState>>? = null

    /**
     * @param value
     */
    @JvmName("odwnqpiphtifaoht")
    public suspend fun includedEvents(`value`: Output<List<String>>) {
        this.includedEvents = value
    }

    @JvmName("eydkswauqbeapvle")
    public suspend fun includedEvents(vararg values: Output<String>) {
        this.includedEvents = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("mnlsqptojyhslrvs")
    public suspend fun includedEvents(values: List<Output<String>>) {
        this.includedEvents = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("pifhcnsxuqewuugo")
    public suspend fun messageScope(`value`: Output<Either<String, MessageScope>>) {
        this.messageScope = value
    }

    /**
     * @param value
     */
    @JvmName("fcbhggkjxsknopjp")
    public suspend fun notificationEndpoints(`value`: Output<List<NotificationEndpointArgs>>) {
        this.notificationEndpoints = value
    }

    @JvmName("atvwkyalggoksgbo")
    public suspend fun notificationEndpoints(vararg values: Output<NotificationEndpointArgs>) {
        this.notificationEndpoints = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("fmlptykhbbvylkmr")
    public suspend fun notificationEndpoints(values: List<Output<NotificationEndpointArgs>>) {
        this.notificationEndpoints = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("oaygycocfklypyww")
    public suspend fun notificationMode(`value`: Output<Either<String, NotificationMode>>) {
        this.notificationMode = value
    }

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("vbjmpglibtrfcxqg")
    public suspend fun provisioningState(`value`: Output<Either<String, ProvisioningState>>) {
        this.provisioningState = value
    }

    /**
     * @param value
     */
    @JvmName("luhvmpwxipurrwgn")
    public suspend fun includedEvents(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedEvents = mapped
    }

    /**
     * @param values
     */
    @JvmName("kkuoncmondypvqnk")
    public suspend fun includedEvents(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedEvents = mapped
    }

    /**
     * @param value
     */
    @JvmName("dyekfxxxpbdpslpd")
    public suspend fun messageScope(`value`: Either<String, MessageScope>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.messageScope = mapped
    }

    /**
     * @param value
     */
    @JvmName("xleadxxfvyungnov")
    public fun messageScope(`value`: String) {
        val toBeMapped = Either.ofLeft<String, MessageScope>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.messageScope = mapped
    }

    /**
     * @param value
     */
    @JvmName("lfxmvtvwvkfjxpbr")
    public fun messageScope(`value`: MessageScope) {
        val toBeMapped = Either.ofRight<String, MessageScope>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.messageScope = mapped
    }

    /**
     * @param value
     */
    @JvmName("nnpnnipgntxwnmkd")
    public suspend fun notificationEndpoints(`value`: List<NotificationEndpointArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notificationEndpoints = mapped
    }

    /**
     * @param argument
     */
    @JvmName("vigcqlxrjohdhlwj")
    public suspend
    fun notificationEndpoints(argument: List<suspend NotificationEndpointArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            NotificationEndpointArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.notificationEndpoints = mapped
    }

    /**
     * @param argument
     */
    @JvmName("gcwoobrmbmujlcor")
    public suspend fun notificationEndpoints(
        vararg
        argument: suspend NotificationEndpointArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            NotificationEndpointArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.notificationEndpoints = mapped
    }

    /**
     * @param argument
     */
    @JvmName("begqawkseihnipoa")
    public suspend
    fun notificationEndpoints(argument: suspend NotificationEndpointArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(NotificationEndpointArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.notificationEndpoints = mapped
    }

    /**
     * @param values
     */
    @JvmName("fthtbnvvvkgksvrm")
    public suspend fun notificationEndpoints(vararg values: NotificationEndpointArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notificationEndpoints = mapped
    }

    /**
     * @param value
     */
    @JvmName("mfivekdbgosptelr")
    public suspend fun notificationMode(`value`: Either<String, NotificationMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notificationMode = mapped
    }

    /**
     * @param value
     */
    @JvmName("rxhdhjytuiipltcg")
    public fun notificationMode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NotificationMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notificationMode = mapped
    }

    /**
     * @param value
     */
    @JvmName("sabyglbjofxphgyv")
    public fun notificationMode(`value`: NotificationMode) {
        val toBeMapped = Either.ofRight<String, NotificationMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notificationMode = mapped
    }

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("wcrrplvflxvdxkjy")
    public suspend fun provisioningState(`value`: Either<String, ProvisioningState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("cgmmvjergtbsnrhi")
    public fun provisioningState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("khelnwjyenmcbqlr")
    public fun provisioningState(`value`: ProvisioningState) {
        val toBeMapped = Either.ofRight<String, ProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    internal fun build(): NotificationRegistrationPropertiesArgs =
        NotificationRegistrationPropertiesArgs(
            includedEvents = includedEvents,
            messageScope = messageScope,
            notificationEndpoints = notificationEndpoints,
            notificationMode = notificationMode,
            provisioningState = provisioningState,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/NotificationRegistrationPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.NotificationRegistrationPropertiesArgs.builder
import com.pulumi.azurenative.providerhub.kotlin.enums.MessageScope
import com.pulumi.azurenative.providerhub.kotlin.enums.NotificationMode
import com.pulumi.azurenative.providerhub.kotlin.enums.ProvisioningState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property includedEvents
 * @property messageScope
 * @property notificationEndpoints
 * @property notificationMode
 * @property provisioningState The provisioned state of the resource.
 */
public data class NotificationRegistrationPropertiesArgs(
    public val includedEvents: Output<List<String>>? = null,
    public val messageScope: Output<Either<String, MessageScope>>? = null,
    public val notificationEndpoints: Output<List<NotificationEndpointArgs>>? = null,
    public val notificationMode: Output<Either<String, NotificationMode>>? = null,
    public val provisioningState: Output<Either<String, ProvisioningState>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.NotificationRegistrationPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.NotificationRegistrationPropertiesArgs =
        com.pulumi.azurenative.providerhub.inputs.NotificationRegistrationPropertiesArgs.builder()
            .includedEvents(includedEvents?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .messageScope(
                messageScope?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .notificationEndpoints(
                notificationEndpoints?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .notificationMode(
                notificationMode?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .provisioningState(
                provisioningState?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            ).build()
}

/**
 * Builder for [NotificationRegistrationPropertiesArgs].
 */
@PulumiTagMarker
public class NotificationRegistrationPropertiesArgsBuilder internal constructor() {
    private var includedEvents: Output<List<String>>? = null

    private var messageScope: Output<Either<String, MessageScope>>? = null

    private var notificationEndpoints: Output<List<NotificationEndpointArgs>>? = null

    private var notificationMode: Output<Either<String, NotificationMode>>? = null

    private var provisioningState: Output<Either<String, ProvisioningState>>? = null

    /**
     * @param value
     */
    @JvmName("bexpqqoqnwcbidgg")
    public suspend fun includedEvents(`value`: Output<List<String>>) {
        this.includedEvents = value
    }

    @JvmName("raplfpfkgudodsyv")
    public suspend fun includedEvents(vararg values: Output<String>) {
        this.includedEvents = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("vrupjgpaspuofnkk")
    public suspend fun includedEvents(values: List<Output<String>>) {
        this.includedEvents = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ygdmihbskrgveqsq")
    public suspend fun messageScope(`value`: Output<Either<String, MessageScope>>) {
        this.messageScope = value
    }

    /**
     * @param value
     */
    @JvmName("dpwtgibyfnhtqkkc")
    public suspend fun notificationEndpoints(`value`: Output<List<NotificationEndpointArgs>>) {
        this.notificationEndpoints = value
    }

    @JvmName("efrtoobwphvfwerd")
    public suspend fun notificationEndpoints(vararg values: Output<NotificationEndpointArgs>) {
        this.notificationEndpoints = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("mxlawpuugeoqncke")
    public suspend fun notificationEndpoints(values: List<Output<NotificationEndpointArgs>>) {
        this.notificationEndpoints = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("lvafsvavowtgpsei")
    public suspend fun notificationMode(`value`: Output<Either<String, NotificationMode>>) {
        this.notificationMode = value
    }

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("lftmaiedmeemiwfs")
    public suspend fun provisioningState(`value`: Output<Either<String, ProvisioningState>>) {
        this.provisioningState = value
    }

    /**
     * @param value
     */
    @JvmName("kaejpxfkaoqqkwgu")
    public suspend fun includedEvents(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedEvents = mapped
    }

    /**
     * @param values
     */
    @JvmName("vyihgqmwlkjqaojo")
    public suspend fun includedEvents(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedEvents = mapped
    }

    /**
     * @param value
     */
    @JvmName("dyrhsoyqdixsmpyj")
    public suspend fun messageScope(`value`: Either<String, MessageScope>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.messageScope = mapped
    }

    /**
     * @param value
     */
    @JvmName("bmskpphyadslrkfs")
    public fun messageScope(`value`: String) {
        val toBeMapped = Either.ofLeft<String, MessageScope>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.messageScope = mapped
    }

    /**
     * @param value
     */
    @JvmName("sjdusnanncpiyvho")
    public fun messageScope(`value`: MessageScope) {
        val toBeMapped = Either.ofRight<String, MessageScope>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.messageScope = mapped
    }

    /**
     * @param value
     */
    @JvmName("dvdmfxtsclnxfenh")
    public suspend fun notificationEndpoints(`value`: List<NotificationEndpointArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notificationEndpoints = mapped
    }

    /**
     * @param argument
     */
    @JvmName("tjxmwwxoytdpkplw")
    public suspend
    fun notificationEndpoints(argument: List<suspend NotificationEndpointArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            NotificationEndpointArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.notificationEndpoints = mapped
    }

    /**
     * @param argument
     */
    @JvmName("rsmgxuqljiqlkucj")
    public suspend fun notificationEndpoints(
        vararg
        argument: suspend NotificationEndpointArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            NotificationEndpointArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.notificationEndpoints = mapped
    }

    /**
     * @param argument
     */
    @JvmName("xyiosrbpysyjdglq")
    public suspend
    fun notificationEndpoints(argument: suspend NotificationEndpointArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(NotificationEndpointArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.notificationEndpoints = mapped
    }

    /**
     * @param values
     */
    @JvmName("abenmmjmcabplgbq")
    public suspend fun notificationEndpoints(vararg values: NotificationEndpointArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notificationEndpoints = mapped
    }

    /**
     * @param value
     */
    @JvmName("qdsmtwwgdtncamje")
    public suspend fun notificationMode(`value`: Either<String, NotificationMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notificationMode = mapped
    }

    /**
     * @param value
     */
    @JvmName("iegcrrpfrujqyylo")
    public fun notificationMode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NotificationMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notificationMode = mapped
    }

    /**
     * @param value
     */
    @JvmName("krdyanfdxakoudom")
    public fun notificationMode(`value`: NotificationMode) {
        val toBeMapped = Either.ofRight<String, NotificationMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notificationMode = mapped
    }

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("hpywffkntewsobql")
    public suspend fun provisioningState(`value`: Either<String, ProvisioningState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("qbgjuiobrchceinp")
    public fun provisioningState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("achbiccsxvmhhuht")
    public fun provisioningState(`value`: ProvisioningState) {
        val toBeMapped = Either.ofRight<String, ProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    internal fun build(): NotificationRegistrationPropertiesArgs =
        NotificationRegistrationPropertiesArgs(
            includedEvents = includedEvents,
            messageScope = messageScope,
            notificationEndpoints = notificationEndpoints,
            notificationMode = notificationMode,
            provisioningState = provisioningState,
        )
}
